@@ -7,9 +7,9 @@ recluster.node.strength <-function (mat, phylo=NULL, dist="simpson", nodelab.cex
 		p<-0.5+((cons-1)*step)
 		treesstr[[cons]]<-recluster.cons(mat,phylo,dist=dist,tr=tr,method=method,p=p)$cons
 	}
-	btr2 <- .compressTipLabel(treesstr)
+	btr2 <- .recluster_compressTipLabel(treesstr)
 	tr2 <- recluster.check(tree1, attr(btr2, "TipLabel"))
-	btr2 <- .uncompressTipLabel(btr2)
+	btr2 <- .recluster_uncompressTipLabel(btr2)
 	result <- prop.clades(tr2, btr2, rooted=T)*(100/levels)
 	recluster.plot(tree1,as.matrix (result), nodelab.cex = nodelab.cex,...)
 	out$result<-as.matrix(result)
